@@ -5,6 +5,7 @@ import qisys.qixml
 import qibuild.config
 import qibuild.profile
 import qitoolchain
+import platform
 
 
 class CMakeBuildConfig(object):
@@ -20,6 +21,7 @@ class CMakeBuildConfig(object):
         self.build_type = "Debug"
         self.user_flags = list()
         self.profiles = list()
+        self.verbose_make = False
         self._default_config = None
         self.qibuild_cfg = self.read_global_qibuild_settings()
         self._cmake_generator = None
@@ -102,6 +104,30 @@ class CMakeBuildConfig(object):
         envsetter.read_config(self.qibuild_cfg)
         return envsetter.get_build_env()
 
+    def build_directory(self, prefix="build"):
+        """ Return a suitable build directory, depending on the
+        build setting of the worktree: the name of the toolchain,
+        the build profiles, and the build type (debug/release)
+        """
+        parts = [prefix]
+        if self.toolchain:
+            parts.append(self.toolchain.name)
+        else:
+            parts.append("sys-%s-%s" % (platform.system().lower(),
+                                        platform.machine().lower()))
+        for profile in self.profiles:
+            parts.append(profile)
+
+        # When using cmake + visual studio, sharing the same build dir with
+        # several build config is mandatory.
+        # Otherwise, it's not a good idea, so we always specify it
+        # when it's not "Debug" (the default)
+        if not self.using_visual_studio:
+            if self.build_type and self.build_type != "Debug":
+                parts.append(self.build_type.lower())
+        return "-".join(parts)
+
+
     @property
     def cmake_args(self):
         """ The CMake arguments to use
